@@ -46,10 +46,10 @@ iheatmap <- function(x, fData = NULL, pData = NULL, impute = FALSE) {
   )
   
   server <- function(input, output) {
-    callModule(
-      iheatmapModule, 'test', 
-      mat = reactive(x), 
-      pd = reactive(pData), 
+    iheatmapModule(
+      'test',
+      mat = reactive(x),
+      pd = reactive(pData),
       fd = reactive(fData))
   }
   
@@ -175,9 +175,7 @@ iheatmapClear <- function(id) {
 
 
 #' @description iheatmap module
-#' @param input input
-#' @param output output
-#' @param session session
+#' @param id module id
 #' @param mat expression matrix
 #' @param pd phenotype data
 #' @param fd feature data
@@ -185,11 +183,13 @@ iheatmapClear <- function(id) {
 #' @param status heatmap states
 #' @importFrom RColorBrewer brewer.pal
 #' @name iheatmap
-#' 
+#'
 iheatmapModule <- function(
-  input, output, session, mat, pd, fd, status = reactive(NULL), fill.NA = TRUE
+  id, mat, pd, fd, status = reactive(NULL), fill.NA = TRUE
   ) {
-  
+
+  moduleServer(id, function(input, output, session) {
+
   ns <- session$ns
   
   matr <- reactive({
@@ -247,7 +247,7 @@ iheatmapModule <- function(
     })
   observe({
     req(pd())
-    updateSelectInput(session, "annotRow", choices = fdColWithGS())
+    updateSelectizeInput(session, "annotRow", choices = fdColWithGS(), server = TRUE)
     }) 
   observe({
     req(pd())
@@ -259,7 +259,7 @@ iheatmapModule <- function(
     ss <- clsRow()
     if (ss == "none" && cs[[1]] != "none")
       ss <- cs[[1]]
-    updateSelectInput( session, "rowSortBy", choices = cs, selected = ss )
+    updateSelectizeInput( session, "rowSortBy", choices = cs, selected = ss, server = TRUE )
     })
   observe({
     req(pd())
@@ -291,9 +291,9 @@ iheatmapModule <- function(
     if (is.null(status()))
       return(NULL)
     updateSelectInput(session, "annotCol", selected = null2empty(status()$annotCol) )
-    updateSelectInput(session, "annotRow", selected  = null2empty(status()$annotRow) )
+    updateSelectizeInput(session, "annotRow", selected  = null2empty(status()$annotRow) )
     updateSelectInput(session, "colSortBy", selected  = status()$colSortBy)
-    updateSelectInput(session, "rowSortBy", selected  = status()$rowSortBy)
+    updateSelectizeInput(session, "rowSortBy", selected  = status()$rowSortBy)
     updateSelectInput(session, "tooltipInfo", selected  = null2empty(status()$tooltipInfo) )
     updateSelectInput(session, "heatmapColors", selected  = status()$heatmapColors)
     updateSelectInput(session, "scale", selected  = status()$scale)
@@ -792,7 +792,7 @@ iheatmapModule <- function(
     tooltip_mouse(res)
   })
 
-  callModule(shinyPlotTooltips, id = "tlp_heatmap", points = tooltip_mouse)
+  shinyPlotTooltips("tlp_heatmap", points = tooltip_mouse)
 
   ############### return ##############
 
@@ -852,5 +852,7 @@ iheatmapModule <- function(
       )
     r
   })
+
+  }) # end moduleServer
 }
 
