@@ -6,27 +6,24 @@ plot_roc_pr_ui <- function(id) {
   )
 }
 
-#' Shiny module for boxplot using plotly - Module
-#' @param input input
-#' @param output output
-#' @param session session
+#' Shiny module for ROC/PR plot - Module
+#' @param id module id
 #' @param reactive_param reactive value; argument pass to draw_roc_pr
 #' @param reactive_checkpoint reactive_value; check this value before render any plot/executing any calculation
-#' @examples 
+#' @examples
 #' if (interactive()) {
 #'   library(shiny)
-#'   
+#'
 #'   ui <- fluidPage(
 #'     sliderInput("ngrp", label = "Number of groups", min = 2, max = 5, value = 2),
 #'     plot_roc_pr_ui("testplot")
 #'   )
-#'   
+#'
 #'   server <- function(input, output, session) {
 #'     ng <- reactive(
 #'       sample(letters[1:input$ngrp], size = 100, replace = TRUE)
 #'     )
-#'     callModule(
-#'       plot_roc_pr_module, id = "testplot",
+#'     plot_roc_pr_module("testplot",
 #'       reactive_param = reactive(list(
 #'         x = ng(),
 #'         y = rnorm(100)
@@ -38,12 +35,16 @@ plot_roc_pr_ui <- function(id) {
 #' @return do not return any values
 
 
-plot_roc_pr_module <- function(input, output, session, reactive_param, reactive_checkpoint = reactive(TRUE)) {
-  
+plot_roc_pr_module <- function(id, reactive_param, reactive_checkpoint = reactive(TRUE)) {
+
+  moduleServer(id, function(input, output, session) {
+
   output$roc_pr <- renderPlot({
     req(reactive_checkpoint())
     draw_roc_pr(reactive_param()$y, reactive_param()$x)
   })
+
+  }) # end moduleServer
 }
 
 
