@@ -95,11 +95,11 @@
 
 plotly_scatter <- function(
   x, y, xlab = "", ylab = "ylab", color = "", shape = "", size = 10, tooltips=NULL, # shape = "circle", color = "defaultColor",
-  regressionLine = FALSE, source = "scatterplotlysource", sizeRange = c(5, 15), 
+  regressionLine = FALSE, source = "scatterplotlysource", sizeRange = c(5, 15),
   highlight = NULL, highlightName = "Highlighted", inSelection = NA,
   vline = NULL, hline = NULL, rect = NULL, drawButtonId = NULL
 ) {
-  options(stringsAsFactors = FALSE)
+  # Note: stringsAsFactors = FALSE is default in R >= 4.0
   
   i1 <- (is.factor(x) || is.character(x) || is.logical(x)) && is.numeric(y) # beeswarm vertical
   i2 <- (is.factor(y) || is.character(y) || is.logical(y)) && is.numeric(x) # beeswarm horizontal
@@ -162,8 +162,8 @@ plotly_scatter <- function(
     tlp <- paste0("<b>", tooltips[df$index], "</b><br>", tlp)
   df$tlp <- tlp
   
-  df$shape[is.na(df$shape)] <- "_NA_"
-  df$color[is.na(df$color)] <- "_NA_"
+  df$shape[is.na(df$shape) | df$shape == "" | df$shape == "NA"] <- "_NA_"
+  df$color[is.na(df$color) | df$color == "" | df$color == "NA"] <- "_NA_"
   df$size[is.na(df$size)] <- min(df$size, na.rm = TRUE)
   if (!is.null(highlight)) {
     df$highlight <- FALSE
@@ -267,8 +267,17 @@ plotly_scatter <- function(
       modeBarButtonsToAdd = modeBarAdd
     )
   
-  return(list(fig = toWebGL(fig), data = df))
-  # return(list(fig = fig, data = df))
+  # Try to convert to WebGL for performance, but fall back to regular plotly if it fails
+  # Note: Some trace types (e.g., markers with custom symbols) may not support WebGL
+  fig_webgl <- tryCatch(
+    toWebGL(fig),
+    error = function(e) {
+      warning("Could not convert plot to WebGL, using standard rendering: ", e$message)
+      fig
+    }
+  )
+
+  return(list(fig = fig_webgl, data = df))
 }
 
 
@@ -352,13 +361,11 @@ plotly_scatter_ui <- function(id, height = "400px") {
 
 #' Shiny module for scatter plot using plotly - Module
 #' @description Function should only be used for the developers
-#' @param input input
-#' @param output output
-#' @param session sesion
+#' @param id module id
 #' @param reactive_param_plotly_scatter reactive parammeters for plotly_scatter
 #' @param reactive_regLine logical show or hide the regression line
 #' @param reactive_checkpoint checkpoint
-#' @param htest_var1 when the plot is a beeswarmplot, two groups could be selected for two group comparison, this 
+#' @param htest_var1 when the plot is a beeswarmplot, two groups could be selected for two group comparison, this
 #'   argument gives the default value. Mainly used for restoring the saved session.
 #' @param htest_var2 see above
 #' @importFrom fastmatch '%fin%'
@@ -367,22 +374,22 @@ plotly_scatter_ui <- function(id, height = "400px") {
 #' @examples
 #' if (interactive()) {
 #'   library(shiny)
-#'   
+#'
 #'   # two random variables
 #'   x <- rnorm(30)
 #'   y <- x + rnorm(30, sd = 0.5)
-#'   
+#'
 #'   # variables mapped to color, shape and size
-#'   cc <- sample(letters[1:4], replace = TRUE, size = 30) 
+#'   cc <- sample(letters[1:4], replace = TRUE, size = 30)
 #'   shape <- sample(c("S1", "S2", "S3"), replace = TRUE, size = 30)
 #'   sz <- sample(c(10, 20, 30, replace = TRUE, size = 30))
-#'   
+#'
 #'   ui <- fluidPage(
 #'     plotly_scatter_ui("test_scatter")
 #'   )
-#'   
+#'
 #'   server <- function(input, output, session) {
-#'     v <- callModule(plotly_scatter_module, id = "test_scatter",
+#'     v <- plotly_scatter_module("test_scatter",
 #'                     # reactive_checkpoint = reactive(FALSE),
 #'                     reactive_param_plotly_scatter = reactive(list(
 #'                       x = x, y = y,
@@ -394,31 +401,31 @@ plotly_scatter_ui <- function(id, height = "400px") {
 #'     observe(print(v()))
 #'   }
 #'   shinyApp(ui, server)
-#'   
-#'   
-#'   
+#'
+#'
+#'
 #'   # example beeswarm horizontal
 #'   x <- rnorm(30)
 #'   y <- sample(c("x", "y", "z"), size = 30, replace = TRUE)
 #'   shinyApp(ui, server)
-#'   
+#'
 #'   # example beeswarm vertical
 #'   x <- sample(c("x", "y", "z"), size = 30, replace = TRUE)
 #'   y <- rnorm(30)
 #'   shinyApp(ui, server)
-#'   
-#'   # return values 
+#'
+#'   # return values
 #'   x <- c(5, 6, 3, 4, 1, 2)
 #'   y <- c(5, 6, 3, 4, 1, 2)
 #'   ui <- fluidPage(
 #'     plotly_scatter_ui("test_scatter")
 #'   )
 #'   server <- function(input, output, session) {
-#'     v <- callModule(plotly_scatter_module, id = "test_scatter",
+#'     v <- plotly_scatter_module("test_scatter",
 #'                     reactive_param_plotly_scatter = reactive(list(
 #'                       x = x, y = y, tooltips = paste("A", 1:6), highlight = 2:4
 #'                     )))
-#'     
+#'
 #'     observe(print(v()))
 #'   }
 #'   shinyApp(ui, server)
@@ -426,11 +433,12 @@ plotly_scatter_ui <- function(id, height = "400px") {
 #' @return an reactive object containing the information of selected, brushed points.
 
 plotly_scatter_module <- function(
-  input, output, session, reactive_param_plotly_scatter, reactive_regLine = reactive(FALSE),
+  id, reactive_param_plotly_scatter, reactive_regLine = reactive(FALSE),
   reactive_checkpoint = reactive(TRUE), htest_var1 = reactive(NULL), htest_var2 = reactive(NULL)
   ) {
-  
-  options(warn = -1)
+
+  moduleServer(id, function(input, output, session) {
+
   ns <- session$ns
   
   hm <- reactive({
@@ -615,6 +623,8 @@ plotly_scatter_module <- function(
       htest_V2 = input$group2
     )
   })
+
+  }) # end moduleServer
 }
 
 
